from setuptools import setup

setup(name='rbg2_distributions',
      version='0.1',
      description='Gaussian distributions',
      author='HyunSuk O',
      author_email='oh_hyunseok@hotmail.com',
      packages=['rbg2_distributions'],
      zip_safe=False)
